Description Usage Arguments Details Value Examples
Extracts parts from the file(s) based on their extension, writes them to disk and process further based on th eoptions given.
extract uses extract.XXX to extract the parts from a file based on the file extension XXX.
option.YYY is used to process the file written to disk further.
1 |
files |
character: a vector with file name(s) |
quiet |
logical: should be info messages suppressed? (default: |
... |
named parameters: the parameter .XXX should contain a regular expression to extract |
Currently are supported:
extract.texextraction from tex files
option.Rfurther processing of R files
You may provide further extract.XXX or option.YYY functions.
invisibly a list of files written to disk
1 2 3 | file <- system.file("example.tex", package="extpro")
d <- diff(file)
d
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.